@@ -44,6 +44,7 @@ from optparse import OptionGroup, OptionParser, Values
 import sys
 from typing import Any, List, Optional, Tuple
 
+from .const import ATTR_ID, ATTR_IPADDR
 from .device import WifiLedBulb
 from .pattern import PresetPattern
 from .scanner import BulbScanner, FluxLEDDiscovery
@@ -394,6 +395,13 @@ def parseArgs() -> Tuple[Values, Any]:  # noqa: C901
     other_group = OptionGroup(parser, "Other options")
 
     parser.add_option_group(info_group)
+    info_group.add_option(
+        "--debug",
+        action="store_true",
+        dest="debug",
+        default=False,
+        help="Enable debug logging",
+    )
     info_group.add_option(
         "-e",
         "--examples",
@@ -588,6 +596,9 @@ def parseArgs() -> Tuple[Values, Any]:  # noqa: C901
     parser.usage = "usage: %prog [-sS10cwdkpCiltThe] [addr1 [addr2 [addr3] ...]."
     (options, args) = parser.parse_args()
 
+    if options.debug:
+        logging.basicConfig(level=logging.DEBUG)
+
     if options.showexamples:
         showUsageExamples()
         sys.exit(0)
@@ -685,9 +696,9 @@ def parseArgs() -> Tuple[Values, Any]:  # noqa: C901
 def main() -> None:  # noqa: C901
 
     (options, args) = parseArgs()
+    scanner = BulbScanner()
 
     if options.scan:
-        scanner = BulbScanner()
         scanner.scan(timeout=6)
         bulb_info_list = scanner.getBulbInfo()
         # we have a list of buld info dicts
@@ -701,22 +712,24 @@ def main() -> None:  # noqa: C901
                 print("  {} {}".format(b["id"], b["ipaddr"]))
             sys.exit(0)
 
-    else:
-        addrs = args
-        bulb_info_list = []
+    elif options.info:
         for addr in args:
-            bulb_info_list.append(FluxLEDDiscovery({"ipaddr": addr, "id": "Unknown ID"}))  # type: ignore
+            scanner.scan(timeout=6, address=addr)
+        bulb_info_list = scanner.getBulbInfo()
+        found_addrs = {discovery[ATTR_IPADDR] for discovery in bulb_info_list}
+        for addr in args:
+            if addr in found_addrs:
+                continue
+            bulb_info_list.append(FluxLEDDiscovery({ATTR_IPADDR: addr, ATTR_ID: "Unknown ID"}))  # type: ignore
 
     # now we have our bulb list, perform same operation on all of them
     for info in bulb_info_list:
         try:
-            bulb = WifiLedBulb(info["ipaddr"])
+            bulb = WifiLedBulb(info["ipaddr"], discovery=info)
         except Exception as e:
             print("Unable to connect to bulb at [{}]: {}".format(info["ipaddr"], e))
             continue
 
-        bulb.discovery = info
-
         if options.getclock:
             print("{} [{}] {}".format(info["id"], info["ipaddr"], bulb.getClock()))
 
